@@ -1,5 +1,5 @@
 /*
-Copyright (c) 2023 Raspberry Pi (Trading) Ltd.
+Copyright (c) 2023 Raspberry Pi
 All rights reserved.
 
 Some code taken from the lxpanel project
@@ -73,7 +73,7 @@ press_t pressed;
 double press_x, press_y;
 
 gboolean touch_only;
-
+int widget_icon_size;
 gboolean is_pi_var;
 
 static GtkWindow *panel, *popwindow;
@@ -95,6 +95,17 @@ GtkWindow *find_panel (GtkWidget *btn)
     return GTK_WINDOW (wid);
 }
 
+gboolean panel_at_bottom (GtkWidget *btn)
+{
+    GtkWindow *panel = find_panel (btn);
+    return gtk_layer_get_anchor (panel, GTK_LAYER_SHELL_EDGE_BOTTOM);
+}
+
+int get_icon_size (void)
+{
+    return widget_icon_size;
+}
+
 void store_layer (GtkLayerShellLayer layer)
 {
     orig_layer = layer;
@@ -116,7 +127,7 @@ void set_menu_icon (GtkWidget *image, const char *icon, int size)
 {
     if (!icon) return;
     GdkPixbuf *pixbuf = gtk_icon_theme_load_icon (gtk_icon_theme_get_default (), icon,
-        size > 32 ? 24 : 16, GTK_ICON_LOOKUP_FORCE_SIZE, NULL);
+        size >= 32 ? 24 : 16, GTK_ICON_LOOKUP_FORCE_SIZE, NULL);
     if (pixbuf)
     {
         gtk_image_set_from_pixbuf (GTK_IMAGE (image), pixbuf);
@@ -351,7 +362,7 @@ void graph_free (PluginGraph *graph)
 
 static gboolean hide_prelight (GtkWidget *btn)
 {
-    gtk_widget_unset_state_flags (btn, GTK_STATE_FLAG_PRELIGHT);
+    if (btn && GTK_IS_WIDGET (btn)) gtk_widget_unset_state_flags (btn, GTK_STATE_FLAG_PRELIGHT);
     return FALSE;
 }
 
